/*
 * File Name: eink-display-update.c
 */

/*
 * This file is part of matchbox-keyboard.
 *
 * matchbox-keyboard is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * matchbox-keyboard is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * Copyright (C) 2008 iRex Technologies B.V.
 * All rights reserved.
 */

//----------------------------------------------------------------------------
// Include Files
//----------------------------------------------------------------------------

// system include files, between < >
#include <arpa/inet.h>
#include <netinet/in.h>
#include <stdio.h>
#include <string.h>
#include <sys/socket.h>
#include <sys/types.h>
#include <unistd.h>

// ereader include files, between < >

// local include files, between " "
//#include "eink-display-update.h"


//----------------------------------------------------------------------------
// Type Declarations
//----------------------------------------------------------------------------


//----------------------------------------------------------------------------
// Constants
//----------------------------------------------------------------------------


//----------------------------------------------------------------------------
// Static Variables
//----------------------------------------------------------------------------

static int      irex_gtk_dump_count = 0;
static int      irex_dump_ignore;

static int      irex_dump_is_window;
static int      irex_dump_window_type;
static int      irex_dump_focus;
static char*    irex_dump_widget_type;

static int      irex_display_socket = -1;
static int      irex_pid = -1;

static struct sockaddr_in irex_display_addr;


//============================================================================
// Local Function Definitions
//============================================================================

static void irex_display_init(void);


//============================================================================
// Functions Implementation
//============================================================================

// create connection to displayMgr
static void irex_display_init(void)
{
    if (irex_display_socket==-1)
    {
        const char addr[] = "127.0.0.1";
        const int  port   = 50555;

        irex_display_socket = socket(PF_INET, SOCK_DGRAM, 0);
        irex_display_addr.sin_family = AF_INET; 
        irex_display_addr.sin_port = htons(port);
        irex_display_addr.sin_addr.s_addr = inet_addr(addr);
        irex_pid = getpid();
        memset(irex_display_addr.sin_zero, '\0', sizeof irex_display_addr.sin_zero);
    }
}

// send a display update message
void irex_display_update_impl(int x, int y, int width, int height)
{
    char msg[256];

    irex_display_init();
    sprintf(msg,"!I,%d,%d,%d,%d,%d,%d,%d,%d,%s,%d", 
            irex_pid,
            x, y, width, height, 
            irex_dump_ignore,
            irex_dump_is_window, 
            irex_dump_window_type, 
            irex_dump_widget_type,
            irex_dump_focus);
    printf("irex_display_update: Sent update message [%s]\n", msg);
    sendto(irex_display_socket, msg, strlen(msg), 0, 
            (struct sockaddr*)&irex_display_addr, sizeof(irex_display_addr));
    irex_dump_focus = 0;
}
